[Bf-blender-cvs] [9ad379fe559] blender2.7: Fix T61891: Cycles light use nodes button greyed out.

Brecht Van Lommel noreply at git.blender.org
Mon Feb 25 10:25:28 CET 2019


Commit: 9ad379fe559200e7a17a3c9571ff0785a095dfac
Author: Brecht Van Lommel
Date:   Mon Feb 25 10:24:40 2019 +0100
Branches: blender2.7
https://developer.blender.org/rB9ad379fe559200e7a17a3c9571ff0785a095dfac

Fix T61891: Cycles light use nodes button greyed out.

===================================================================

M	intern/cycles/blender/addon/operators.py

===================================================================

diff --git a/intern/cycles/blender/addon/operators.py b/intern/cycles/blender/addon/operators.py
index a099970c58c..28657de24d4 100644
--- a/intern/cycles/blender/addon/operators.py
+++ b/intern/cycles/blender/addon/operators.py
@@ -22,22 +22,22 @@ from bpy.props import StringProperty
 
 
 class CYCLES_OT_use_shading_nodes(Operator):
     """Enable nodes on a material, world or light"""
     bl_idname = "cycles.use_shading_nodes"
     bl_label = "Use Nodes"
 
     @classmethod
     def poll(cls, context):
         return (getattr(context, "material", False) or getattr(context, "world", False) or
-                getattr(context, "light", False))
+                getattr(context, "lamp", False))
 
     def execute(self, context):
         if context.material:
             context.material.use_nodes = True
         elif context.world:
             context.world.use_nodes = True
-        elif context.light:
-            context.light.use_nodes = True
+        elif context.lamp:
+            context.lamp.use_nodes = True
 
         return {'FINISHED'}
@@ -22,22 +22,22 @@ from bpy.props import StringProperty
 
 class CYCLES_OT_use_shading_nodes(Operator):
-    """Enable nodes on a material, world or light"""
+    """Enable nodes on a material, world or lamp"""
     bl_idname = "cycles.use_shading_nodes"
     bl_label = "Use Nodes"



More information about the Bf-blender-cvs mailing list